@@ -5,12 +5,12 @@ plugins {
 defaultTasks("run")
 
 // tag::run[]
-task("run") {
+tasks.register("run") {
     dependsOn(gradle.includedBuild("my-app").task(":run"))
 }
 // end::run[]
 
-task("checkAll") {
+tasks.register("checkAll") {
     dependsOn(gradle.includedBuild("my-app").task(":check"))
     dependsOn(gradle.includedBuild("my-utils").task(":number-utils:check"))
     dependsOn(gradle.includedBuild("my-utils").task(":string-utils:check"))
