@@ -26,19 +26,19 @@ fun javaExecutable(execName: String): String {
     require(executable.exists()) { "There is no $execName executable in $javaExecutablesPath" }
     return executable.toString()
 }
-tasks.withType<JavaCompile> {
+tasks.withType<JavaCompile>().configureEach {
     options.apply {
         isFork = true
         forkOptions.javaHome = file(java6Home)
     }
 }
-tasks.withType<Javadoc> {
+tasks.withType<Javadoc>().configureEach {
     executable = javaExecutable("javadoc")
 }
-tasks.withType<Test> {
+tasks.withType<Test>().configureEach {
     executable = javaExecutable("java")
 }
-tasks.withType<JavaExec> {
+tasks.withType<JavaExec>.configureEach {
     executable = javaExecutable("java")
 }
 // end::groovy-cross-compilation[]
