@@ -14,7 +14,7 @@ val rpmArtifact = artifacts.add("archives", rpmFile) {
 }
 // end::custom-artifact[]
 
-task("rpm") {
+tasks.register("rpm") {
     outputs.file(rpmFile)
     doLast {
         // produce real RPM here
