@@ -1,13 +1,13 @@
 import com.enterprise.DocsGenerate
 
-task<DocsGenerate>("generateHtmlDocs") {
+tasks.register<DocsGenerate>("generateHtmlDocs") {
     group = JavaBasePlugin.DOCUMENTATION_GROUP
     description = "Generates the HTML documentation for this project."
     title = "Project docs"
     outputDir = file("$buildDir/docs")
 }
 
-task("allDocs") {
+tasks.register("allDocs") {
     group = JavaBasePlugin.DOCUMENTATION_GROUP
     description = "Generates all documentation for this project."
     dependsOn("generateHtmlDocs")
