@@ -2,12 +2,9 @@ open class Person {
     var name: String? = null
 }
 
-open class GreetingPluginExtension(val greeter: Person) {
+open class GreetingPluginExtension @javax.inject.Inject constructor(objectFactory: ObjectFactory) {
     var message: String? = null
-
-    // Create a Person instance
-    @javax.inject.Inject
-    constructor(objectFactory: ObjectFactory): this(objectFactory.newInstance<Person>())
+    val greeter: Person = objectFactory.newInstance()
 
     fun greeter(action: Action<in Person>) {
         action.execute(greeter)
@@ -16,8 +13,8 @@ open class GreetingPluginExtension(val greeter: Person) {
 
 class GreetingPlugin : Plugin<Project> {
     override fun apply(project: Project) {
-        // Create the extension, passing in an ObjectFactory for it to use
-        val extension = project.extensions.create<GreetingPluginExtension>("greeting", project.objects)
+        // Create the 'greeting' extension
+        val extension = project.extensions.create<GreetingPluginExtension>("greeting")
         project.task("hello") {
             doLast {
                 println("${extension.message} from ${extension.greeter.name}")
