@@ -1,15 +1,20 @@
 allprojects {
-    task("hello") {
+    tasks.register("hello") {
         doLast {
             println("I'm ${this.project.name}")
         }
     }
 }
 subprojects {
-    tasks.getByName("hello") {
+    val hello by tasks.existing
+
+    hello {
         doLast { println("- I depend on water") }
-        afterEvaluate {
-            if (extra["arctic"] as Boolean) {
+    }
+
+    afterEvaluate {
+        if (extra["arctic"] as Boolean) {
+            hello {
                 doLast {
                     println("- I love to spend time in the arctic waters.")
                 }
