@@ -1,27 +1,29 @@
-val taskX by tasks.creating {
+val taskX by tasks.registering {
     doLast {
         println("taskX")
     }
 }
 
 // Using a Gradle Provider
-taskX.dependsOn(provider {
-    tasks.filter { task -> task.name.startsWith("lib") }
-})
+taskX {
+    dependsOn(provider {
+        tasks.filter { task -> task.name.startsWith("lib") }
+    })
+}
 
-task("lib1") {
+tasks.register("lib1") {
     doLast {
         println("lib1")
     }
 }
 
-task("lib2") {
+tasks.register("lib2") {
     doLast {
         println("lib2")
     }
 }
 
-task("notALib") {
+tasks.register("notALib") {
     doLast {
         println("notALib")
     }
