@@ -1,12 +1,12 @@
-val taskX by tasks.creating {
+val taskX by tasks.registering {
     doLast {
         println("taskX")
     }
 }
-val taskY by tasks.creating {
+val taskY by tasks.registering {
     doLast {
         println("taskY")
     }
 }
 
-taskX.finalizedBy(taskY)
+taskX { finalizedBy(taskY) }
