@@ -1,11 +1,11 @@
-val taskX by tasks.creating {
+val taskX by tasks.registering {
     doLast {
         println("taskX")
     }
 }
-val taskY by tasks.creating {
+val taskY by tasks.registering {
     doLast {
         println("taskY")
     }
 }
-taskY.shouldRunAfter(taskX)
+taskY { shouldRunAfter(taskX) }
