@@ -1,5 +1,5 @@
 repeat(4) { counter ->
-    task("task$counter") {
+    tasks.register("task$counter") {
         doLast {
             println("I'm task number $counter")
         }
