@@ -1,8 +1,8 @@
 repeat(4) { counter ->
-    task("task$counter") {
+    tasks.register("task$counter") {
         doLast {
             println("I'm task number $counter")
         }
     }
 }
-tasks["task0"].dependsOn("task2", "task3")
+tasks.named("task0") { dependsOn("task2", "task3") }
